pub struct Client<C, M, R = Standard> { /* private fields */ }Expand description
An ergonomic service client for KvService.
This client allows ergonomic access to a KvService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Constructing a Client
To construct a client, you need a few different things:
- A
Configthat specifies additional configuration required by the service. - A connector (
C) that specifies how HTTP requests are translated into HTTP responses. This will typically be an HTTP client (likehyper), though you can also substitute in your own, like a mock mock connector for testing. - A “middleware” (
M) that modifies requests prior to them being sent to the request. Most commonly, middleware will decide what endpoint the requests should be sent to, as well as perform authentication and authorization of requests (such as SigV4). You can also have middleware that performs request/response tracing, throttling, or other middleware-like tasks. - A retry policy (
R) that dictates the behavior for requests that fail and should (potentially) be retried. The default type is generally what you want, as it implements a well-vetted retry policy implemented inRetryMode::Standard.
To construct a client, you will generally want to call
Client::with_config, which takes a aws_smithy_client::Client (a
Smithy client that isn’t specialized to a particular service),
and a Config. Both of these are constructed using
the builder pattern where you first construct a Builder type,
then configure it with the necessary parameters, and then call
build to construct the finalized output type. The
aws_smithy_client::Client builder is re-exported in this crate as
Builder for convenience.
In most circumstances, you will want to use the following pattern to construct a client:
use rivet_kv::{Builder, Client, Config};
let raw_client =
Builder::dyn_https()
.middleware(/* discussed below */)
.build();
let config = Config::builder().build();
let client = Client::with_config(raw_client, config);For the middleware, you’ll want to use whatever matches the routing, authentication and authorization required by the target service. For example, for the standard AWS SDK which uses SigV4-signed requests, the middleware looks like this:
use aws_endpoint::AwsEndpointStage;
use aws_http::auth::CredentialsStage;
use aws_http::recursion_detection::RecursionDetectionStage;
use aws_http::user_agent::UserAgentStage;
use aws_sig_auth::middleware::SigV4SigningStage;
use aws_sig_auth::signer::SigV4Signer;
use aws_smithy_client::retry::Config as RetryConfig;
use aws_smithy_http_tower::map_request::{AsyncMapRequestLayer, MapRequestLayer};
use std::fmt::Debug;
use tower::layer::util::{Identity, Stack};
use tower::ServiceBuilder;
type AwsMiddlewareStack = Stack<
MapRequestLayer<RecursionDetectionStage>,
Stack<
MapRequestLayer<SigV4SigningStage>,
Stack<
AsyncMapRequestLayer<CredentialsStage>,
Stack<
MapRequestLayer<UserAgentStage>,
Stack<MapRequestLayer<AwsEndpointStage>, Identity>,
>,
>,
>,
>;
/// AWS Middleware Stack
///
/// This implements the middleware stack for this service. It will:
/// 1. Load credentials asynchronously into the property bag
/// 2. Sign the request with SigV4
/// 3. Resolve an Endpoint for the request
/// 4. Add a user agent to the request
#[derive(Debug, Default, Clone)]
#[non_exhaustive]
pub struct AwsMiddleware;
impl AwsMiddleware {
/// Create a new `AwsMiddleware` stack
///
/// Note: `AwsMiddleware` holds no state.
pub fn new() -> Self {
AwsMiddleware::default()
}
}
// define the middleware stack in a non-generic location to reduce code bloat.
fn base() -> ServiceBuilder<AwsMiddlewareStack> {
let credential_provider = AsyncMapRequestLayer::for_mapper(CredentialsStage::new());
let signer = MapRequestLayer::for_mapper(SigV4SigningStage::new(SigV4Signer::new()));
let endpoint_resolver = MapRequestLayer::for_mapper(AwsEndpointStage);
let user_agent = MapRequestLayer::for_mapper(UserAgentStage::new());
let recursion_detection = MapRequestLayer::for_mapper(RecursionDetectionStage::new());
// These layers can be considered as occurring in order, that is:
// 1. Resolve an endpoint
// 2. Add a user agent
// 3. Acquire credentials
// 4. Sign with credentials
// (5. Dispatch over the wire)
ServiceBuilder::new()
.layer(endpoint_resolver)
.layer(user_agent)
.layer(credential_provider)
.layer(signer)
.layer(recursion_detection)
}
impl<S> tower::Layer<S> for AwsMiddleware {
type Service = <AwsMiddlewareStack as tower::Layer<S>>::Service;
fn layer(&self, inner: S) -> Self::Service {
base().service(inner)
}
}Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
Sourceimpl<C, M, R> Client<C, M, R>
impl<C, M, R> Client<C, M, R>
Sourcepub fn delete(&self) -> Delete<C, M, R>
pub fn delete(&self) -> Delete<C, M, R>
Constructs a fluent builder for the Delete operation.
- The fluent builder is configurable:
key(impl Into<String>)/set_key(Option<String>): A string reprenting a key in the key-value database. Key path components are split by a slash (e.g.a/b/chas the path components["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g.a/b\/c/dhas the path components["a", "b/c", "d"]). Seerivet.api.kv.common#KeyComponentsfor the structure of arivet.api.kv.common#Keysplit by/.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
DeleteOutput - On failure, responds with
SdkError<DeleteError>
Sourcepub fn delete_batch(&self) -> DeleteBatch<C, M, R>
pub fn delete_batch(&self) -> DeleteBatch<C, M, R>
Constructs a fluent builder for the DeleteBatch operation.
- The fluent builder is configurable:
keys(Vec<String>)/set_keys(Option<Vec<String>>): A list of keys.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
DeleteBatchOutput - On failure, responds with
SdkError<DeleteBatchError>
Sourcepub fn get(&self) -> Get<C, M, R>
pub fn get(&self) -> Get<C, M, R>
Constructs a fluent builder for the Get operation.
- The fluent builder is configurable:
key(impl Into<String>)/set_key(Option<String>): A string reprenting a key in the key-value database. Key path components are split by a slash (e.g.a/b/chas the path components["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g.a/b\/c/dhas the path components["a", "b/c", "d"]). Seerivet.api.kv.common#KeyComponentsfor the structure of arivet.api.kv.common#Keysplit by/.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
GetOutputwith field(s):value(Option<Document>): The key’s JSON value.deleted(Option<bool>): Whether or not the entry has been deleted. Only set when watching this endpoint.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetError>
Sourcepub fn get_batch(&self) -> GetBatch<C, M, R>
pub fn get_batch(&self) -> GetBatch<C, M, R>
Constructs a fluent builder for the GetBatch operation.
- The fluent builder is configurable:
keys(Vec<String>)/set_keys(Option<Vec<String>>): A list of keys.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
GetBatchOutputwith field(s):entries(Option<Vec<KvEntry>>): A list of key-value entries.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetBatchError>
Sourcepub fn put(&self) -> Put<C, M, R>
pub fn put(&self) -> Put<C, M, R>
Constructs a fluent builder for the Put operation.
- The fluent builder is configurable:
namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.key(impl Into<String>)/set_key(Option<String>): Any JSON value to set the key to.value(Document)/set_value(Option<Document>): (undocumented)
- On success, responds with
PutOutput - On failure, responds with
SdkError<PutError>
Sourcepub fn put_batch(&self) -> PutBatch<C, M, R>
pub fn put_batch(&self) -> PutBatch<C, M, R>
Constructs a fluent builder for the PutBatch operation.
- The fluent builder is configurable:
namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.entries(Vec<PutEntry>)/set_entries(Option<Vec<PutEntry>>): A list of entries to insert.
- On success, responds with
PutBatchOutput - On failure, responds with
SdkError<PutBatchError>