pub struct ClientWrapper { /* private fields */ }Expand description
A wrapper around Client. Helps reduce external imports.
Methods from Deref<Target = Client<DynConnector, Identity>>
Sourcepub fn delete(&self) -> Delete<C, M, R>
pub fn delete(&self) -> Delete<C, M, R>
Constructs a fluent builder for the Delete operation.
- The fluent builder is configurable:
key(impl Into<String>)/set_key(Option<String>): A string reprenting a key in the key-value database. Key path components are split by a slash (e.g.a/b/chas the path components["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g.a/b\/c/dhas the path components["a", "b/c", "d"]). Seerivet.api.kv.common#KeyComponentsfor the structure of arivet.api.kv.common#Keysplit by/.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
DeleteOutput - On failure, responds with
SdkError<DeleteError>
Sourcepub fn delete_batch(&self) -> DeleteBatch<C, M, R>
pub fn delete_batch(&self) -> DeleteBatch<C, M, R>
Constructs a fluent builder for the DeleteBatch operation.
- The fluent builder is configurable:
keys(Vec<String>)/set_keys(Option<Vec<String>>): A list of keys.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
DeleteBatchOutput - On failure, responds with
SdkError<DeleteBatchError>
Sourcepub fn get(&self) -> Get<C, M, R>
pub fn get(&self) -> Get<C, M, R>
Constructs a fluent builder for the Get operation.
- The fluent builder is configurable:
key(impl Into<String>)/set_key(Option<String>): A string reprenting a key in the key-value database. Key path components are split by a slash (e.g.a/b/chas the path components["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g.a/b\/c/dhas the path components["a", "b/c", "d"]). Seerivet.api.kv.common#KeyComponentsfor the structure of arivet.api.kv.common#Keysplit by/.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
GetOutputwith field(s):value(Option<Document>): The key’s JSON value.deleted(Option<bool>): Whether or not the entry has been deleted. Only set when watching this endpoint.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetError>
Sourcepub fn get_batch(&self) -> GetBatch<C, M, R>
pub fn get_batch(&self) -> GetBatch<C, M, R>
Constructs a fluent builder for the GetBatch operation.
- The fluent builder is configurable:
keys(Vec<String>)/set_keys(Option<Vec<String>>): A list of keys.watch_index(impl Into<String>)/set_watch_index(Option<String>): A query parameter denoting the requests watch index.namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.
- On success, responds with
GetBatchOutputwith field(s):entries(Option<Vec<KvEntry>>): A list of key-value entries.watch(Option<WatchResponse>): Provided by watchable endpoints used in blocking loops.
- On failure, responds with
SdkError<GetBatchError>
Sourcepub fn put(&self) -> Put<C, M, R>
pub fn put(&self) -> Put<C, M, R>
Constructs a fluent builder for the Put operation.
- The fluent builder is configurable:
namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.key(impl Into<String>)/set_key(Option<String>): Any JSON value to set the key to.value(Document)/set_value(Option<Document>): (undocumented)
- On success, responds with
PutOutput - On failure, responds with
SdkError<PutError>
Sourcepub fn put_batch(&self) -> PutBatch<C, M, R>
pub fn put_batch(&self) -> PutBatch<C, M, R>
Constructs a fluent builder for the PutBatch operation.
- The fluent builder is configurable:
namespace_id(impl Into<String>)/set_namespace_id(Option<String>): A universally unique identifier.entries(Vec<PutEntry>)/set_entries(Option<Vec<PutEntry>>): A list of entries to insert.
- On success, responds with
PutBatchOutput - On failure, responds with
SdkError<PutBatchError>