#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for GetInput
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn key(self, input: impl Into<String>) -> Self
pub fn key(self, input: impl Into<String>) -> Self
A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
Sourcepub fn set_key(self, input: Option<String>) -> Self
pub fn set_key(self, input: Option<String>) -> Self
A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
Sourcepub fn watch_index(self, input: impl Into<String>) -> Self
pub fn watch_index(self, input: impl Into<String>) -> Self
A query parameter denoting the requests watch index.
Sourcepub fn set_watch_index(self, input: Option<String>) -> Self
pub fn set_watch_index(self, input: Option<String>) -> Self
A query parameter denoting the requests watch index.
Sourcepub fn namespace_id(self, input: impl Into<String>) -> Self
pub fn namespace_id(self, input: impl Into<String>) -> Self
A universally unique identifier.
Sourcepub fn set_namespace_id(self, input: Option<String>) -> Self
pub fn set_namespace_id(self, input: Option<String>) -> Self
A universally unique identifier.