#[non_exhaustive]pub struct DeleteInput {
pub key: Option<String>,
pub namespace_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: Option<String>A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
namespace_id: Option<String>A universally unique identifier.
Implementations
Sourceimpl DeleteInput
impl DeleteInput
Sourcepub async fn make_operation(
&self,
_config: &Config,
) -> Result<Operation<Delete, ()>, BuildError>
pub async fn make_operation( &self, _config: &Config, ) -> Result<Operation<Delete, ()>, BuildError>
Consumes the builder and constructs an Operation<Delete>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeleteInput
Sourceimpl DeleteInput
impl DeleteInput
Sourcepub fn key(&self) -> Option<&str>
pub fn key(&self) -> Option<&str>
A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
Sourcepub fn namespace_id(&self) -> Option<&str>
pub fn namespace_id(&self) -> Option<&str>
A universally unique identifier.