#[non_exhaustive]pub struct GetInput {
pub key: Option<String>,
pub watch_index: Option<String>,
pub namespace_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: Option<String>A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
watch_index: Option<String>A query parameter denoting the requests watch index.
namespace_id: Option<String>A universally unique identifier.
Implementations
Sourceimpl GetInput
impl GetInput
Sourcepub fn key(&self) -> Option<&str>
pub fn key(&self) -> Option<&str>
A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
Sourcepub fn watch_index(&self) -> Option<&str>
pub fn watch_index(&self) -> Option<&str>
A query parameter denoting the requests watch index.
Sourcepub fn namespace_id(&self) -> Option<&str>
pub fn namespace_id(&self) -> Option<&str>
A universally unique identifier.