#[non_exhaustive]pub struct PutEntry {
pub key: Option<String>,
pub value: Option<Document>,
}Expand description
A new entry to insert into the key-value database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: Option<String>A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
value: Option<Document>Implementations
Sourceimpl PutEntry
impl PutEntry
Sourcepub fn key(&self) -> Option<&str>
pub fn key(&self) -> Option<&str>
A string reprenting a key in the key-value database. Key path components are split by a slash (e.g. a/b/c has the path components ["a", "b", "c"]). Slashes can be escaped by using a forward slash (e.g. a/b\/c/d has the path components ["a", "b/c", "d"]). See rivet.api.kv.common#KeyComponents for the structure of a rivet.api.kv.common#Key split by /.
pub fn value(&self) -> Option<&Document>